.. scinumtools documentation master file, created by
   sphinx-quickstart on Fri Jul 14 22:16:15 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scinumtools's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   cached_function
   image_thumbnails
   quantity
   api/modules
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
